@@ -9,7 +9,7 @@ class KedClient(AbstractClient):
     _endpoint = 'ked.api.ksyun.com'
     _service = 'ked'
     def CloudDeskreinstall(self, request):
-        """云电脑重装系统
+        """允许用户对一个或多个云电脑实例执行系统重装操作。
         :param request: Request instance for CloudDeskreinstall.
         :type request: :class:`ksyun.client.ked.v20250501.models.CloudDeskreinstallRequest`
         """
@@ -32,7 +32,7 @@ class KedClient(AbstractClient):
 
 
     def CloudDeskmanage(self, request):
-        """云电脑开机/关机/重启
+        """提供对云电脑进行开机、关机、重启、删除、锁定和解锁的操作功能。
         :param request: Request instance for CloudDeskmanage.
         :type request: :class:`ksyun.client.ked.v20250501.models.CloudDeskmanageRequest`
         """
@@ -55,7 +55,7 @@ class KedClient(AbstractClient):
 
 
     def CloudDeskedit(self, request):
-        """云电脑列表编辑
+        """修改云电脑实例的名称
         :param request: Request instance for CloudDeskedit.
         :type request: :class:`ksyun.client.ked.v20250501.models.CloudDeskeditRequest`
         """
@@ -78,7 +78,7 @@ class KedClient(AbstractClient):
 
 
     def CloudDeskcreate(self, request):
-        """云电脑创建
+        """此接口允许用户通过提供必要的参数（如实例名称、类型、镜像ID等）来创建新的云电脑实例。
         :param request: Request instance for CloudDeskcreate.
         :type request: :class:`ksyun.client.ked.v20250501.models.CloudDeskcreateRequest`
         """
@@ -101,13 +101,13 @@ class KedClient(AbstractClient):
 
 
     def CloudDesklist(self, request):
-        """云电脑列表管理
+        """该接口用于获取用户所拥有的所有云电脑实例的列表，支持分页查询，并能根据连接状态过滤结果。
         :param request: Request instance for CloudDesklist.
         :type request: :class:`ksyun.client.ked.v20250501.models.CloudDesklistRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("CloudDesklist", params, "application/json")
+            body = self.call_judge("CloudDesklist", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -124,7 +124,7 @@ class KedClient(AbstractClient):
 
 
     def Strategyruleedit(self, request):
-        """修改策略组API
+        """修改已有的策略安全组规则。
         :param request: Request instance for Strategyruleedit.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategyruleeditRequest`
         """
@@ -147,7 +147,7 @@ class KedClient(AbstractClient):
 
 
     def Strategyrulecreate(self, request):
-        """新建策略组规则API
+        """创建一个新的策略安全组规则。
         :param request: Request instance for Strategyrulecreate.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategyrulecreateRequest`
         """
@@ -170,7 +170,7 @@ class KedClient(AbstractClient):
 
 
     def Strategyunbound(self, request):
-        """策略安全组解绑云电脑API
+        """解除当前云电脑与安全组的绑定关系。
         :param request: Request instance for Strategyunbound.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategyunboundRequest`
         """
@@ -193,7 +193,7 @@ class KedClient(AbstractClient):
 
 
     def Strategybound(self, request):
-        """策略安全组绑定云电脑API
+        """将指定云电脑与策略安全组绑定。
         :param request: Request instance for Strategybound.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategyboundRequest`
         """
@@ -216,7 +216,7 @@ class KedClient(AbstractClient):
 
 
     def Strategydelete(self, request):
-        """策略安全组删除API
+        """删除指定的策略安全组。
         :param request: Request instance for Strategydelete.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategydeleteRequest`
         """
@@ -239,7 +239,7 @@ class KedClient(AbstractClient):
 
 
     def Strategyedit(self, request):
-        """策略安全组修改API
+        """修改现有策略安全组的信息。
         :param request: Request instance for Strategyedit.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategyeditRequest`
         """
@@ -262,7 +262,7 @@ class KedClient(AbstractClient):
 
 
     def Strategycreate(self, request):
-        """策略安全组创建API
+        """创建一个新的策略安全组。
         :param request: Request instance for Strategycreate.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategycreateRequest`
         """
@@ -285,13 +285,13 @@ class KedClient(AbstractClient):
 
 
     def Strategylist(self, request):
-        """策略安全组列表API
+        """获取特定云电脑的安全组列表。
         :param request: Request instance for Strategylist.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategylistRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("Strategylist", params, "application/json")
+            body = self.call_judge("Strategylist", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -308,7 +308,7 @@ class KedClient(AbstractClient):
 
 
     def Rolesdelete(self, request):
-        """角色删除API
+        """删除指定角色。
         :param request: Request instance for Rolesdelete.
         :type request: :class:`ksyun.client.ked.v20250501.models.RolesdeleteRequest`
         """
@@ -331,7 +331,7 @@ class KedClient(AbstractClient):
 
 
     def Rolesedit(self, request):
-        """角色修改API
+        """更新角色属性。
         :param request: Request instance for Rolesedit.
         :type request: :class:`ksyun.client.ked.v20250501.models.RoleseditRequest`
         """
@@ -354,7 +354,7 @@ class KedClient(AbstractClient):
 
 
     def Rolescreate(self, request):
-        """角色创建API
+        """创建新角色，支持配置相应权限。
         :param request: Request instance for Rolescreate.
         :type request: :class:`ksyun.client.ked.v20250501.models.RolescreateRequest`
         """
@@ -377,13 +377,13 @@ class KedClient(AbstractClient):
 
 
     def Roleslist(self, request):
-        """角色管理列表API
+        """显示所有角色列表及其详细信息。
         :param request: Request instance for Roleslist.
         :type request: :class:`ksyun.client.ked.v20250501.models.RoleslistRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("Roleslist", params, "application/json")
+            body = self.call_judge("Roleslist", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -400,7 +400,7 @@ class KedClient(AbstractClient):
 
 
     def Imagedelete(self, request):
-        """镜像删除API
+        """删除指定的镜像。
         :param request: Request instance for Imagedelete.
         :type request: :class:`ksyun.client.ked.v20250501.models.ImagedeleteRequest`
         """
@@ -423,7 +423,7 @@ class KedClient(AbstractClient):
 
 
     def Imageedit(self, request):
-        """镜像修改API
+        """编辑已有镜像的信息。
         :param request: Request instance for Imageedit.
         :type request: :class:`ksyun.client.ked.v20250501.models.ImageeditRequest`
         """
@@ -446,7 +446,7 @@ class KedClient(AbstractClient):
 
 
     def Imagecreate(self, request):
-        """镜像创建API
+        """创建自定义镜像。
         :param request: Request instance for Imagecreate.
         :type request: :class:`ksyun.client.ked.v20250501.models.ImagecreateRequest`
         """
@@ -469,13 +469,13 @@ class KedClient(AbstractClient):
 
 
     def Imagelist(self, request):
-        """镜像管理列表API
+        """列出所有可用的镜像资源列表。
         :param request: Request instance for Imagelist.
         :type request: :class:`ksyun.client.ked.v20250501.models.ImagelistRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("Imagelist", params, "application/json")
+            body = self.call_judge("Imagelist", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -492,7 +492,7 @@ class KedClient(AbstractClient):
 
 
     def StrategyrulebatchEdit(self, request):
-        """批量配置策略组规则API
+        """批量删除策略安全组规则。
         :param request: Request instance for StrategyrulebatchEdit.
         :type request: :class:`ksyun.client.ked.v20250501.models.StrategyrulebatchEditRequest`
         """
@@ -515,13 +515,13 @@ class KedClient(AbstractClient):
 
 
     def Monitorregions(self, request):
-        """区域列表API
+        """返回系统支持的所有地理区域的列表，包括其显示名称和对应的值。
         :param request: Request instance for Monitorregions.
         :type request: :class:`ksyun.client.ked.v20250501.models.MonitorregionsRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("Monitorregions", params, "application/json")
+            body = self.call_judge("Monitorregions", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -538,7 +538,7 @@ class KedClient(AbstractClient):
 
 
     def Usersinstancebind(self, request):
-        """用户绑定云电脑
+        """将云电脑分配给指定用户。
         :param request: Request instance for Usersinstancebind.
         :type request: :class:`ksyun.client.ked.v20250501.models.UsersinstancebindRequest`
         """
@@ -561,7 +561,7 @@ class KedClient(AbstractClient):
 
 
     def Userspasswordreset(self, request):
-        """用户重置密码API
+        """重新设置用户密码。
         :param request: Request instance for Userspasswordreset.
         :type request: :class:`ksyun.client.ked.v20250501.models.UserspasswordresetRequest`
         """
@@ -584,7 +584,7 @@ class KedClient(AbstractClient):
 
 
     def Usersdelete(self, request):
-        """用户删除API
+        """删除指定用户账户。
         :param request: Request instance for Usersdelete.
         :type request: :class:`ksyun.client.ked.v20250501.models.UsersdeleteRequest`
         """
@@ -607,7 +607,7 @@ class KedClient(AbstractClient):
 
 
     def Usersedit(self, request):
-        """用户修改API
+        """更改相关用户资料。
         :param request: Request instance for Usersedit.
         :type request: :class:`ksyun.client.ked.v20250501.models.UserseditRequest`
         """
@@ -630,7 +630,7 @@ class KedClient(AbstractClient):
 
 
     def Userscreate(self, request):
-        """用户创建API
+        """注册新用户。
         :param request: Request instance for Userscreate.
         :type request: :class:`ksyun.client.ked.v20250501.models.UserscreateRequest`
         """
@@ -653,13 +653,358 @@ class KedClient(AbstractClient):
 
 
     def Userslist(self, request):
-        """用户列表API
+        """查看所有用户的概览信息。
         :param request: Request instance for Userslist.
         :type request: :class:`ksyun.client.ked.v20250501.models.UserslistRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("Userslist", params, "application/json")
+            body = self.call_judge("Userslist", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def CloudDeskgetDesktopUrl(self, request):
+        """根据授权toen生成一个可以直接进入云电脑的URL
+        :param request: Request instance for CloudDeskgetDesktopUrl.
+        :type request: :class:`ksyun.client.ked.v20250501.models.CloudDeskgetDesktopUrlRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("CloudDeskgetDesktopUrl", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def QueryCloudDesksubmitShell(self, request):
+        """提交一个可执行的脚本，支持ps1,bat脚本,请注意脚本的后缀,".ps1"的后缀会使用powershell 执行
+        :param request: Request instance for QueryCloudDesksubmitShell.
+        :type request: :class:`ksyun.client.ked.v20250501.models.QueryCloudDesksubmitShellRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("QueryCloudDesksubmitShell", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def CreateCloudDeskgetToken(self, request):
+        """KOP鉴权通过之后，使用此接口可生成一个token用于快速登录云电脑
+        :param request: Request instance for CreateCloudDeskgetToken.
+        :type request: :class:`ksyun.client.ked.v20250501.models.CreateCloudDeskgetTokenRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("CreateCloudDeskgetToken", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def QueryShellStatus(self, request):
+        """查询下发的脚本运行状态
+        :param request: Request instance for QueryShellStatus.
+        :type request: :class:`ksyun.client.ked.v20250501.models.QueryShellStatusRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("QueryShellStatus", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def SetProxyIp(self, request):
+        """支持在云电脑里配置出口代理
+        :param request: Request instance for SetProxyIp.
+        :type request: :class:`ksyun.client.ked.v20250501.models.SetProxyIpRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("SetProxyIp", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def GetProxyConfig(self, request):
+        """查询出口代理ip
+        :param request: Request instance for GetProxyConfig.
+        :type request: :class:`ksyun.client.ked.v20250501.models.GetProxyConfigRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("GetProxyConfig", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def QueryRuledetail(self, request):
+        """根据策略组id查询策略规则详情
+        :param request: Request instance for QueryRuledetail.
+        :type request: :class:`ksyun.client.ked.v20250501.models.QueryRuledetailRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("QueryRuledetail", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def QueryUsersinfo(self, request):
+        """查询注册时的用户账号信息，不支持模糊查询
+        :param request: Request instance for QueryUsersinfo.
+        :type request: :class:`ksyun.client.ked.v20250501.models.QueryUsersinfoRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("QueryUsersinfo", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def GetDetail(self, request):
+        """查询云电脑实例详情信息
+        :param request: Request instance for GetDetail.
+        :type request: :class:`ksyun.client.ked.v20250501.models.GetDetailRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("GetDetail", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def ListLabel(self, request):
+        """查询所有标签
+        :param request: Request instance for ListLabel.
+        :type request: :class:`ksyun.client.ked.v20250501.models.ListLabelRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("ListLabel", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def CancelInstanceLabel(self, request):
+        """解绑云电脑已绑定的标签
+        :param request: Request instance for CancelInstanceLabel.
+        :type request: :class:`ksyun.client.ked.v20250501.models.CancelInstanceLabelRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("CancelInstanceLabel", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def UpdateInstanceLabel(self, request):
+        """绑定标签到云电脑
+        :param request: Request instance for UpdateInstanceLabel.
+        :type request: :class:`ksyun.client.ked.v20250501.models.UpdateInstanceLabelRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("UpdateInstanceLabel", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def DeleteLabel(self, request):
+        """删除一个或多个标签，删除标签后，已绑定过此标签的云桌面上的标签都将被删除
+        :param request: Request instance for DeleteLabel.
+        :type request: :class:`ksyun.client.ked.v20250501.models.DeleteLabelRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("DeleteLabel", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def UpdateLabel(self, request):
+        """修改标签名
+        :param request: Request instance for UpdateLabel.
+        :type request: :class:`ksyun.client.ked.v20250501.models.UpdateLabelRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("UpdateLabel", params, "application/json")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
+    def CreateLabel(self, request):
+        """创建一个标签，用于分类管理云桌面
+        :param request: Request instance for CreateLabel.
+        :type request: :class:`ksyun.client.ked.v20250501.models.CreateLabelRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("CreateLabel", params, "application/json")
             response = json.loads(body)
             if "Error" not in response:
                 return body
